expected power averages the power curve over a Prior conditional on p >= pmcr where pmcr is the minimal clinically relevant response probability. For a PointMass prior, expected power reduces to power at the respective probability atom.

Power(prior, bounds = NULL)

Arguments

prior

Prior object

pmcr

minimal clinically relevant response rate

See also

Examples

# \donttest{ load_julia_package() design <- Design(c(0, 25, 20, 11, 0, 0, 0), c(Inf, 10, 8, 6, -Inf, -Inf, -Inf)) power <- Power(Beta(5, 7) >= 0.3) # unconditional expected power evaluate(power, design)
#> [1] 0.5531565
# expected power given 2 out of 4 responses in stage one evaluate(power, design, partial = c(2, 4))
#> [1] 0.5872499
# expected power given 1 stage-one response evaluate(power, design, x1 = 1)
#> [1] 0.4237216
# expected power given 1 stage one response and 8 out of 12 stage two responses evaluate(power, design, x1 = 1, partial = c(8, 12))
#> [1] 0.9643757
utility <- 80*Power(Beta(5, 7) >= 0.3) - SampleSize(Beta(5, 7)) evaluate(utility, design)
#> [1] 25.88261
# }