Objective functions for optimal two-stage designs

minimise_maximal_sample_size(lambda, prior)

minimise(score)

maximise(score)

Arguments

lambda

minimax sample size alone does not always lead to a unique minimiser. Instead a combination of (1 - lambda) times the maximal sample size and lambda times the expected sample size under the given prior is minimised.

prior

Prior object

score

Score object to be minimised/maximised

See also