Score objects allows the computation of conditional and unconditional performance measures for Design objects. The evaluate generic function and its methods allow to compute scores conditional on observed (partial) stage one results or stage two results or completely unconditional.

evaluate(score, design, ...)

# S4 method for Score,Design
evaluate(score, design, x1 = NULL, partial = c(0, 0))

Arguments

score

Score object to evaluate

design

Design object to evaluate score on

x1

completely observed number of stage one responses under design; if given, thew score is evaluated conditional on x1

partial

partial observations c(x, n) in stage two (if x1 is given) or stage one (if x1 is not given)

See also